function MakeArray() {
	this[0] = MakeArray['arguments'].length;
    var i;
	for (i = 0; i < MakeArray['arguments'].length; i = i + 1) {
		this[i + 1] = MakeArray['arguments'][i];
    }
}

var hodashim = new MakeArray('Tishrì', 'Cheshvan', 'Kislev', 'Tevet', 'Shevat', 'Adar', 'Adar II', 'Nisan', 'Iyar', 'Sivan', 'Tamuz', 'Av', 'Elul');

var hebMonth = new MakeArray('Nisan', 'Iyar', 'Sivan', 'Tamuz', 'Av', 'Elul', 'Tishrì', 'Cheshvan', 'Kislev', 'Tevet', 'Shevat', 'Adar', 'Adar I', 'Adar II');

var civMonth = new MakeArray('Gennaio', 'Febbraio', 'Marzo', 'Aprile', 'Maggio', 'Giugno', 'Luglio', 'Agosto', 'Settembre', 'Ottobre', 'Novembre', 'Dicembre');

function Gauss(year) {
	var a, b, c;
	var m;
	var	Mar;	// "day in March" on which Pesach falls (return value)

	a = Math.floor((12 * year + 17) % 19);
	b = Math.floor(year % 4);
	m = 32.044093161144 + 1.5542417966212 * a +  b / 4.0 - 0.0031777940220923 * year;
	if (m < 0)
		m -= 1;
	Mar = Math.floor(m);
	if (m < 0)
		m++;
	m -= Mar;

	c = Math.floor((Mar + 3 * year + 5 * b + 5) % 7);
	if(c == 0 && a > 11 && m >= 0.89772376543210 )
		Mar++;
	else if(c == 1 && a > 6 && m >= 0.63287037037037)
		Mar += 2;
	else if(c == 2 || c == 4 || c == 6)
		Mar++;

	Mar += Math.floor((year - 3760) / 100) - Math.floor((year - 3760) / 400) - 2;
	return Mar;
}

function leap(y) {
	return ((y % 400 == 0) || (y % 100 != 0 && y % 4 == 0));
}

function civMonthLength(month, year) {
	if(month == 2)
		return 28 + leap(year);
	else if(month == 4 || month == 6 || month == 9 || month == 11)
	   return 30;
	else
		return 31;
}

function civ2heb(day, month, year) {
	var d = day;
	var	m = month;
	var y = year;
	var hy;
	var pesach;
	var anchor;
	var adarType;

	m -= 2;
	if (m <= 0) { // Jan or Feb
		m += 12;
		y -= 1;
	}

	d += Math.floor(7 * m / 12 + 30 * (m - 1)); // day in March
	hy = y + 3760;	// get Hebrew year
	pesach = Gauss(hy);
	if (d <= pesach - 15) { // before 1 Nisan
		anchor = pesach;
		d += 365;
		if(leap(y))
			d++;
		y -= 1;
		hy -= 1;
		pesach = Gauss(hy);
	}
	else
		anchor = Gauss(hy + 1);

	d -= pesach - 15;
	anchor -= pesach - 12;
	y++;
	if(leap(y))
		anchor++;

	for(m = 0; m < 11; m++) {
		var days;
		if(m == 7 && anchor % 30 == 2)
			days = 30; // Cheshvan
		else if(m == 8 && anchor % 30 == 0)
			days = 29; // Kislev
		else
			days = 30 - m % 2;
		if(d <= days)
			break;
		d -= days;
	}

	adarType = 0;			// plain old Adar
	if (m == 11 && anchor >= 30) {
		if (d > 30) {
			adarType = 2;	// Adar 2
			d -= 30;
		}
		else
			adarType = 1;	// Adar 1
	}

	if(m >= 6)		// Tishrei or after?
		hy++;		// then bump up year

	if(m == 11)			// Adar?
		m += adarType;	// adjust for Adars

	return (d + ' ' + m + ' ' + hy);
}


function Easter(Y) {
	// based on the algorithm of Oudin
    var C = Math.floor(Y / 100);
    var N = Y - 19 * Math.floor(Y / 19);
    var K = Math.floor((C - 17) / 25);
    var I = C - Math.floor(C / 4) - Math.floor((C - K) / 3) + 19 * N + 15;
    I = I - 30*Math.floor((I / 30));
    I = I - Math.floor(I / 28) * (1 - Math.floor(I / 28) * Math.floor(29 / (I + 1)) * Math.floor((21 - N) / 11));
    var J = Y + Math.floor(Y / 4) + I + 2 - C + Math.floor(C / 4);
    J = J - 7 * Math.floor(J / 7);
    var L = I - J;
    var M = 3 + Math.floor((L + 40) / 44);
    var D = L + 28 - 31 * Math.floor(M / 4);

	var ret = new Object();
	ret[1] = M;
	ret[2] = D;
	return ret;
}

function DOW(day,month,year) {
	var a = Math.floor((14 - month)/12);
	var y = year - a;
	var m = month + 12*a - 2;
	var d = (day + y + Math.floor(y/4) - Math.floor(y/100) +
			Math.floor(y/400) + Math.floor((31*m)/12)) % 7;
	return d + 1;
}

function NthDOW(nth,weekday,month,year) {
	if (nth > 0)
		return (nth - 1) * 7 + 1 + (7 + weekday - DOW((nth - 1) * 7 + 1, month, year)) % 7;
	var days = civMonthLength(month, year);
	return days - (DOW(days, month, year) - weekday + 7) % 7;
}

function addDays(date, days) {
    var result = new Date(date);
    result.setDate(date.getDate() + days);
    return result;
}

function dateDiffInDays(a, b) {
  var _MS_PER_DAY = 1000 * 60 * 60 * 24;
  var utc1 = Date.UTC(a.getFullYear(), a.getMonth(), a.getDate());
  var utc2 = Date.UTC(b.getFullYear(), b.getMonth(), b.getDate());
  return Math.floor((utc2 - utc1) / _MS_PER_DAY);
}

function nhy(shana) {
    var one_day=1000*60*60*24;
    data0=HebToGreg(1, 1, shana);
    data1=HebToGreg(1, 1, shana+1);
    n=Math.ceil((data1.getTime()-data0.getTime())/one_day);
    return {
        rosh_hashana: data0.getDay(),
        n_giorni: n
    };
}

// Funzione che restituisce un array con tutte le parashot dell'anno ebraico
// in modo da sapere quando due parashot si leggono insieme
// Vediamo se Rosh Hashana è lunedì => 2, martedì => 3, giovedì => 5, sabato => 7     
// Calcoliamo il numero di giorni nell'anno ebraico specificato
function n_parashot(shana){
    var ret = nhy(shana);
    var rosh_hashana = ret.rosh_hashana + 1;
    var n_giorni = ret.n_giorni;
    var parashot;
    if (n_giorni==353 && rosh_hashana==2){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,55,
        24,25,26,56,57,31,58,
        34,35,36,37,38,39,40,41,60,
        44,45,46,47,48,49,50,61,53,54
        ];}

    if (n_giorni==355 && rosh_hashana==2){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,55,
        24,25,26,56,57,31,58,
        34,35,36,37,38,59,41,60,
        44,45,46,47,48,49,50,61,53,54
        ];}

    if (n_giorni==383 && rosh_hashana==2){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,22,23,
        24,25,26,27,28,29,30,31,32,33,
        34,35,36,37,38,59,41,60,
        44,45,46,47,48,49,50,61,53,54
        ];}

    if (n_giorni==385 && rosh_hashana==2){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,22,23,
        24,25,26,27,28,29,30,31,32,33,
        34,35,36,37,38,39,40,41,60,
        44,45,46,47,48,49,50,51,52,53,54
        ];}

    if (n_giorni==354 && rosh_hashana==3){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,55,
        24,25,26,56,57,31,58,
        34,35,36,37,38,59,41,60,
        44,45,46,47,48,49,50,61,53,54
        ];}

    if (n_giorni==384 && rosh_hashana==3){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,22,23,
        24,25,26,27,28,29,30,31,32,33,
        34,35,36,37,38,39,40,41,60,
        44,45,46,47,48,49,50,51,52,53,54
        ];}

    if (n_giorni==353 && rosh_hashana==7){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,55,
        24,25,26,56,57,31,58,
        34,35,36,37,38,39,40,41,60,
        44,45,46,47,48,49,50,51,52,53,54
        ];}

    if (n_giorni==355 && rosh_hashana==7){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,55,
        24,25,26,56,57,31,58,
        34,35,36,37,38,39,40,41,60,
        44,45,46,47,48,49,50,61,53,54
        ];}

    if (n_giorni==383 && rosh_hashana==7){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,22,23,
        24,25,26,27,28,29,30,31,32,33,
        34,35,36,37,38,39,40,41,60,
        44,45,46,47,48,49,50,61,53,54
        ];}

    if (n_giorni==385 && rosh_hashana==7){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,22,23,
        24,25,26,27,28,29,30,31,32,33,
        34,35,36,37,38,59,41,60,
        44,45,46,47,48,49,50,61,53,54
        ];}

    if (n_giorni==354 && rosh_hashana==5){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,55,
        24,25,26,56,57,31,58,
        34,35,36,37,38,39,40,41,60,
        44,45,46,47,48,49,50,51,52,53,54
        ];}

    if (n_giorni==355 && rosh_hashana==5){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,22,23,
        24,25,26,56,57,31,58,
        34,35,36,37,38,39,40,41,60,
        44,45,46,47,48,49,50,51,52,53,54
        ];}


    if (n_giorni==383 && rosh_hashana==5){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,22,23,
        24,25,26,27,28,29,30,31,32,33,
        34,35,36,37,38,39,40,41,42,43,
        44,45,46,47,48,49,50,51,52,53,54
        ];}

   if (n_giorni==385 && rosh_hashana==5){ parashot=[null,
        1,2,3,4,5,6,7,8,9,10,11,12,
        13,14,15,16,17,18,19,20,21,22,23,
        24,25,26,27,28,29,30,31,32,33,
        34,35,36,37,38,39,40,41,42,43,
        44,45,46,47,48,49,50,61,53,54
        ];}

return parashot;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di festa: Rosh Hashana, Kippur, Pesach, Shavuot o Succot
function is_jholiday(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var is__jholiday=false;
    if((dh.hodesh==1 &&  $.inArray(dh.yom, [1,2,10,15,16,17,18,19,20,21,22,23])>=0)
    || (dh.hodesh==8  && $.inArray(dh.yom, [15,16,17,18,19,20,21,22])>=0)
    || (dh.hodesh==10 && $.inArray(dh.yom, [6,7])>=0))
        {is__jholiday=true;}
return is__jholiday;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di festa ebraico
function festeH(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var w  = d.getDay();
    var f = !(((anno+1) % 4) || (!((anno+1) % 100) && ((anno+1) % 400)));
    var b = (nhy(dh.shana).n_giorni > 365 );
    var festeH = '';
   	if ( dh.hodesh == 1  && (dh.yom == 1  || dh.yom == 2) )                 {festeH = 'Rosh Hashanà';}
    if ( dh.hodesh == 1  && dh.yom == 10 )                                  {festeH = 'Yom Kippur';}
   	if ( dh.hodesh == 1  && dh.yom == 3  && w != 6 )                        {festeH = 'Digiuno di Ghedalià';}
    if ( dh.hodesh == 1  && dh.yom == 4  && w == 0 )                        {festeH = 'Digiuno di Ghedalià';}
    if ( dh.hodesh == 1  && dh.yom > 14 && dh.yom < 22)                     {festeH = 'Succot';}
    if ( dh.hodesh == 1  && dh.yom == 22)                                   {festeH = 'Sheminì Atzeret';}
    if ( dh.hodesh == 1  && dh.yom == 23)                                   {festeH = 'Simchat Torà';}
    var d0 = HebToGreg(24,3,dh.shana);
    var chanukka = dateDiffInDays (d0, d);
    if ( chanukka > 0 && chanukka < 9 )                                     {festeH = 'Chanukkà';}
    if ( dh.hodesh == 4  && dh.yom == 10 )                                  {festeH = 'Digiuno del 10 di Tevet';}
    if ( dh.hodesh == 5  && dh.yom == 15 )                                  {festeH = 'Tu BiShvat';}
    if ( dh.hodesh == 6  && dh.yom == 13 && w != 6 && b == false )          {festeH = 'Digiuno di Ester';}
    if ( dh.hodesh == 6  && dh.yom == 11 && w == 4 && b == false )          {festeH = 'Digiuno di Ester';}
    if ( dh.hodesh == 7  && dh.yom == 13 && w != 6 && b == true  )          {festeH = 'Digiuno di Ester';}
    if ( dh.hodesh == 7  && dh.yom == 11 && w == 4 && b == true  )          {festeH = 'Digiuno di Ester';}
    if ( dh.hodesh == 6  && dh.yom == 7 )                                   {festeH = 'Morte di Mosè';}
    if ( dh.hodesh == 6  && dh.yom == 14 && b == false)                     {festeH = 'Purim';}
    if ( dh.hodesh == 7  && dh.yom == 14 && b == true )                     {festeH = 'Purim';}
    if ( dh.hodesh == 6  && dh.yom == 14 && b == true)                      {festeH = 'Purim Katan';}    
    if ( dh.hodesh == 6  && dh.yom == 15 && b == false)                     {festeH = 'Purim Shushan';}
    if ( dh.hodesh == 7  && dh.yom == 15 && b == true )                     {festeH = 'Purim Shushan';}
    if ( dh.hodesh == 6  && dh.yom == 15 && b == true)                      {festeH = 'Purim Sh. Katan';}
    if ( dh.hodesh == 8  && dh.yom == 14 && w != 6 )                        {festeH = 'Digiuno dei primogeniti';}
    if ( dh.hodesh == 8  && dh.yom == 12 && w == 4 )                        {festeH = 'Digiuno dei primogeniti';}
    if ( dh.hodesh == 8  && dh.yom >  14 && dh.yom < 23 )                   {festeH = 'Pesach';}
    if ( dh.hodesh == 10 && dh.yom >  5  && dh.yom < 8  )                   {festeH = 'Shavuot';}
    if ( dh.hodesh == 9  && dh.yom == 3 && w == 4 )                         {festeH = "Yom Ha'Atzmaut";}
    if ( dh.hodesh == 9  && dh.yom == 4 && w == 4 )                         {festeH = "Yom Ha'Atzmaut";}
    if ( dh.hodesh == 9  && dh.yom == 5 && w != 1 && w != 5 && w != 6 )     {festeH = "Yom Ha'Atzmaut";}
    if ( dh.hodesh == 9  && dh.yom == 6 && w == 2 )                         {festeH = "Yom Ha'Atzmaut";}
    if ( dh.hodesh == 9  && dh.yom == 2 && w == 3 )                         {festeH = "Yom Hazikkaron";}
    if ( dh.hodesh == 9  && dh.yom == 3 && w == 3 )                         {festeH = "Yom Hazikkaron";}
    if ( dh.hodesh == 9  && dh.yom == 4 && w != 0 && w != 4 && w != 5 )     {festeH = "Yom Hazikkaron";}
    if ( dh.hodesh == 9  && dh.yom == 5 && w == 1 )                         {festeH = "Yom Hazikkaron";}
    if ( dh.hodesh == 9  && dh.yom == 14 )                                  {festeH = 'Pesach sheni';}
    if ( dh.hodesh == 9  && dh.yom == 18 )                                  {festeH = 'Lag BaOmer';}    
    if ( dh.hodesh == 9  && dh.yom == 28 )                                  {festeH = 'Yom Yerushalaim';}
    if ( dh.hodesh == 11 && dh.yom == 17 && w != 6 )                        {festeH = 'Digiuno del 17 di Tamuz';}
    if ( dh.hodesh == 11 && dh.yom == 18 && w == 0 )                        {festeH = 'Digiuno del 17 di Tamuz';}
    if ( dh.hodesh == 12 && dh.yom == 9  && w != 6 )                        {festeH = 'Digiuno del 9 di Av';}
    if ( dh.hodesh == 12 && dh.yom == 10 && w == 0 )                        {festeH = 'Digiuno del 9 di Av';}
    if ( dh.hodesh == 12 && dh.yom == 15)                                   {festeH = 'Tu BeAv';}
    if ( dh.hodesh == 13 && dh.yom == 2)                                    {festeH = 'Selichot sefarditi';}
    if ( dh.hodesh == 13 && dh.yom == 25)                                   {festeH = 'Inizia la creazione';}
    if ( d.getDate()== 4 && d.getMonth()+1 == 12 && f == false)             {if (festeH != ''){festeH += '<br />';} festeH += 'Veten tal umatar';}
    if ( d.getDate()== 5 && d.getMonth()+1 == 12 && f == true)              {if (festeH != ''){festeH += '<br />';} festeH += 'Veten tal umatar';}
    return festeH;
}

// Funzione che verifica se la data passata come argomento è relativa a un venerdì o alla vigilia di un giorno di festa solenne
function accensione(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    if (d.getDay() == 5) {return true;}
    var accensione=false;
    var dh = GregToHeb(d);
    if((dh.hodesh==13 && $.inArray(dh.yom, [29])>=0)
    || (dh.hodesh==1  && $.inArray(dh.yom, [1,9,14,15,21,22])>=0)    
    || (dh.hodesh==8  && $.inArray(dh.yom, [14,15,20,21])>=0)
    || (dh.hodesh==10 && $.inArray(dh.yom, [5,6])>=0))
        {accensione=true;}
return accensione;
}

// Funzione che verifica se la data passata come argomento è relativa alla vigilia del 9 di Av
function vigilia9av(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var w = d.getDay();
    var vigilia9av=false;
    var dh = GregToHeb(d);
    if(
        dh.hodesh == 12 && dh.yom == 8  && w != 5                // digiuno del 9 di Av
    ||  dh.hodesh == 12 && dh.yom == 9 && w == 6)                // digiuno del 9 di Av posticipato alla domenica
        {vigilia9av=true;}
return vigilia9av;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di digiuno che dura dall'alba all'uscita delle stelle
function isDigiunoAlbaTramonto(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var w  = d.getDay();
    var b = (nhy(dh.shana).n_giorni > 365 );
    var is_digiuno_alba_tramonto=false;
   	if(dh.hodesh == 1  && dh.yom == 3  && w != 6                // digiuno di Ghedalià
    || dh.hodesh == 1  && dh.yom == 4  && w == 0                // digiuno di Ghedalià
    || dh.hodesh == 4  && dh.yom == 10                          // digiuno del 10 di Tevet
    || dh.hodesh == 6  && dh.yom == 13 && w != 6 && b == false  // digiuno di Ester
    || dh.hodesh == 6  && dh.yom == 11 && w == 4 && b == false  // digiuno di Ester
    || dh.hodesh == 7  && dh.yom == 13 && w != 6 && b == true   // digiuno di Ester
    || dh.hodesh == 7  && dh.yom == 11 && w == 4 && b == true   // digiuno di Ester
    || dh.hodesh == 8  && dh.yom == 14 && w != 6                // digiuno dei primogeniti
    || dh.hodesh == 8  && dh.yom == 12 && w == 4                // digiuno dei primogeniti
    || dh.hodesh == 11 && dh.yom == 17 && w != 6                // digiuno del 17 di Tamuz
    || dh.hodesh == 11 && dh.yom == 18 && w == 0                // digiuno del 17 di Tamuz
    ){is_digiuno_alba_tramonto=true;}
return is_digiuno_alba_tramonto;
}

// Funzione che verifica se è da segnalare l'orario dell'uscita delle stelle: shabbat o un giorno di festa solenne seguito da un giorno feriale o di mezza festa, oppure un girono di digiuno
function uscitaStelle(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var w = d.getDay();
    if (w == 5) {return false;}
    if (w == 6) {return true;}
    var uscitaStelle = false;
    var dh = GregToHeb(d);
    if((dh.hodesh==1    && $.inArray(dh.yom, [2,10,16,23])>=0)
    || (dh.hodesh==8    && $.inArray(dh.yom, [16,22])>=0)
    || (dh.hodesh==10   && $.inArray(dh.yom, [7])>=0)
   	|| (dh.hodesh == 1  && dh.yom == 3  && w != 6)                // digiuno di Ghedalià
    || (dh.hodesh == 1  && dh.yom == 4  && w == 0)                // digiuno di Ghedalià
    || (dh.hodesh == 4  && dh.yom == 10)                          // digiuno del 10 di Tevet
    || (dh.hodesh == 6  && dh.yom == 13 && w != 6 && b == false)  // digiuno di Ester
    || (dh.hodesh == 6  && dh.yom == 11 && w == 4 && b == false)  // digiuno di Ester
    || (dh.hodesh == 7  && dh.yom == 13 && w != 6 && b == true)   // digiuno di Ester
    || (dh.hodesh == 7  && dh.yom == 11 && w == 4 && b == true)   // digiuno di Ester
    || (dh.hodesh == 8  && dh.yom == 14 && w != 6)                // digiuno dei primogeniti
    || (dh.hodesh == 8  && dh.yom == 12 && w == 4)                // digiuno dei primogeniti
    || (dh.hodesh == 11 && dh.yom == 17 && w != 6)                // digiuno del 17 di Tamuz
    || (dh.hodesh == 11 && dh.yom == 18 && w == 0)                // digiuno del 17 di Tamuz
    || (dh.hodesh == 12 && dh.yom == 9  && w != 6)                // digiuno del 9 di Av
    || (dh.hodesh == 12 && dh.yom == 10 && w == 0)                // digiuno del 9 di Av
    )
        {uscitaStelle = true;}
return uscitaStelle;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di Yamim Noraim: Rosh Hashana o Kippur
function isYamimNoraim(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var is_yamim_noraim=false;
    if((dh.hodesh==1 &&  $.inArray(dh.yom, [1,2,10])>=0)) {is_yamim_noraim=true;}
return is_yamim_noraim;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di festa solenne di Shalosh Regalim: i primi due o gli ultimi due di Pesach, Shavuot, i primi due di Succot, Shemini Atzeret o Simchat Tora
function isFestaSolenne(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var is_festa_solenne=false;
    if((dh.hodesh==1  && $.inArray(dh.yom, [15,16,22,23])>=0)
    || (dh.hodesh==8  && $.inArray(dh.yom, [15,16,21,22])>=0)
    || (dh.hodesh==10 && $.inArray(dh.yom, [6,7])>=0))
        {is_festa_solenne=true;}
return is_festa_solenne;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di mezza festa: i quattro giorni centrali di Pesach, gli ultimi cinque giorni di Succot
function isMezzaFesta(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var is_mezza_festa=false;
    if((dh.hodesh==1  && $.inArray(dh.yom, [17,18,19,20,21])>=0)
    || (dh.hodesh==8  && $.inArray(dh.yom, [17,18,19,20])>=0))
        {is_mezza_festa=true;}
return is_mezza_festa;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di festa postbiblica: Hanukka e Purim
function isFestaPostbiblica(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var ret= nhy(dh.shana);
    var is_postbiblica=false;
    if((ret.n_giorni < 365 && dh.hodesh==6 &&  $.inArray(dh.yom, [14])>=0)
    || (ret.n_giorni > 365 && dh.hodesh==7  && $.inArray(dh.yom, [14])>=0))
        {is_postbiblica=true;}
    var d0 = HebToGreg(24,3,dh.shana);
    var chanukka = dateDiffInDays (d0, d);
    if (chanukka>0 && chanukka<9) { is_postbiblica = true;}
        
return is_postbiblica;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di digiuno postbiblico
function isDigiunoPostbiblico(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var w  = d.getDay();
    var b = (nhy(dh.shana).n_giorni > 365 );
    var is_digiuno_postbiblico=false;
   	if((dh.hodesh == 1  && dh.yom == 3  && w != 6)                // digiuno di Ghedalià
    || (dh.hodesh == 1  && dh.yom == 4  && w == 0)                // digiuno di Ghedalià
    || (dh.hodesh == 4  && dh.yom == 10)                          // digiuno del 10 di Tevet
    || (dh.hodesh == 6  && dh.yom == 13 && w != 6 && b == false)  // digiuno di Ester
    || (dh.hodesh == 6  && dh.yom == 11 && w == 4 && b == false)  // digiuno di Ester
    || (dh.hodesh == 7  && dh.yom == 13 && w != 6 && b == true)   // digiuno di Ester
    || (dh.hodesh == 7  && dh.yom == 11 && w == 4 && b == true)   // digiuno di Ester
    || (dh.hodesh == 8  && dh.yom == 14 && w != 6)                // digiuno dei primogeniti
    || (dh.hodesh == 8  && dh.yom == 12 && w == 4)                // digiuno dei primogeniti
    || (dh.hodesh == 11 && dh.yom == 17 && w != 6)                // digiuno del 17 di Tamuz
    || (dh.hodesh == 11 && dh.yom == 18 && w == 0)                // digiuno del 17 di Tamuz
    || (dh.hodesh == 12 && dh.yom == 9  && w != 6)                // digiuno del 9 di Av
    || (dh.hodesh == 12 && dh.yom == 10 && w == 0)                // digiuno del 9 di Av
    ){is_digiuno_postbiblico=true;}
return is_digiuno_postbiblico;
}

// Funzione che verifica se la data passata come argomento è relativa a un giorno di Rosh Chodesh
function isRoshChodesh(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var is_rosh_chodesh=false;
    if( dh.yom == 30 || ( dh.yom == 1 && dh.hodesh != 1 ) ){ is_rosh_chodesh=true; }
return is_rosh_chodesh;
}

// Funzione che verifica se la data passata come argomento è relativa a uno Shabbat precedente Rosh Chodesh
function isShabbatMevarechim(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var w  = d.getDay();
    var is_shabbat_mevarechim=false;
    if( w == 6 && dh.yom >= 23 && dh.yom < 30 ){ is_shabbat_mevarechim=true; }
return is_shabbat_mevarechim;
}

// Funzione che verifica se la data passata come argomento è relativa allo Shabbat tra Rosh Ashana e Kippur
function isShabbatSegnalato(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var w  = d.getDay();
    var b = (nhy(dh.shana).n_giorni > 365 );
    var shabbatSegnalato = '';
    if(   w == 6 && dh.hodesh == 1 && dh.yom > 2 && dh.yom < 10 ){ shabbatSegnalato = 'Sh. Shuva'; }
    if( ( w == 6 && b == false && dh.hodesh == 5 && dh.yom >= 25 ) 
    ||  ( w == 6 && b == false && dh.hodesh == 6 && dh.yom == 1  )
    ||  ( w == 6 && b == true  && dh.hodesh == 6 && dh.yom >= 25 )
    ||  ( w == 6 && b == true  && dh.hodesh == 7 && dh.yom == 1  )
    ){ shabbatSegnalato = 'Sh. Shekalim'; }
    if( ( w == 6 && b == false && dh.hodesh == 6 && dh.yom >= 7 && dh.yom < 14 ) 
    ||  ( w == 6 && b == true  && dh.hodesh == 7 && dh.yom >= 7 && dh.yom < 14 )
    ){ shabbatSegnalato = 'Sh. Zachor'; }
    if( ( w == 6 && b == false && dh.hodesh == 6 && dh.yom >= 17 && dh.yom <= 23 )
    ||  ( w == 6 && b == true  && dh.hodesh == 7 && dh.yom >= 17 && dh.yom <= 23 )
    ){ shabbatSegnalato = 'Sh. Parà'; }
    if( ( w == 6 && dh.hodesh == 8 && dh.yom == 1) 
    ||  ( w == 6 && b == false && dh.hodesh == 6 && dh.yom >= 24)
    ||  ( w == 6 && b == true  && dh.hodesh == 7 && dh.yom >= 24)
    ){ shabbatSegnalato = 'Sh. Hachodesh'; }
    if  ( w == 6 && dh.hodesh == 8  && dh.yom >= 8  && dh.yom <= 14 ) { shabbatSegnalato = 'Sh. Haggadol'; }
    if  ( w == 6 && dh.hodesh == 12 && dh.yom >= 3  && dh.yom <= 9  ) { shabbatSegnalato = 'Sh. Chazon'; }
    if  ( w == 6 && dh.hodesh == 12 && dh.yom >= 10 && dh.yom <= 16 ) { shabbatSegnalato = 'Sh. Nachamù'; }
return shabbatSegnalato;
}

// Funzione che restituisce il giorno dell'Omer relativo alla data passata come parametro. Restituisce false se non si tratta di un giorno dell'Omer
function isOmer(giorno, mese, anno){
    var d  = new Date(anno,mese-1,giorno);
    var dh = GregToHeb(d);
    var is_omer=false;
    var d0 = HebToGreg(15,8,dh.shana);
    var omer = dateDiffInDays (d0, d);
    if (omer>0 && omer<50) { is_omer = omer;}
    return is_omer;
}
// Funzione che restituisce la data jd dello Shabbat Bereshit dell'anno ebraico passato come parametro
function shabbat_bereshit(shana){
    var yom = 23; var hodesh = 1; // Data ebraica di Simchat Tora    
    var jd_bereshit = HebToGreg(yom,hodesh,shana);
    while (jd_bereshit.getDay() != 6) {jd_bereshit.setDate(jd_bereshit.getDate()+1);}  // Troviamo il primo shabbat dopo Simchat Tora

return jd_bereshit;
}

// Funzione che restituisce la parashà del sabato
// Riceve come parametri il giorno, mese e anno
// Se la data richiesta non è un sabato, restituisce a parashà del sabato successivo 
function parasha (giorno, mese, anno){
    // array con i nomi delle parashot secondo il libro "Torah e Haftaroth con Rashi"
    var parashot=[null, "Bereshìt","Nòakh","Lech lechà","Vayerà","Khayé Sarà","Toledòt","Vayetzé","Vayishlàkh","Vayéshev","Mikkètz","Vayiggàsh","Vaykhì",           // 12
                "Shemòt","Vaerà","Bò","Beshallach","Itrò","Mishpathìm","Terumà","Tetzavvé ","Ki Tissà","Vayakèl","Pekudé",                                          // 23
                "Vaikrà","Tzàv","Sheminì","Tazrìa","Metzorà","Akharé Mot","Kedoshìm","Emòr","Behàr","Bekhukkotài",                                                  // 33
                "Bemidbàr","Nasò","Behaalotechà","Shelàkh","Kòrakh","Khukkàt","Balàk","Pinekhàs","Mattòt","Mas’é",                                                  // 43
                "Devarìm","Vaetkhannàn","Ékev ","Re’é","Shofetìm","Ki Tetzé","Ki Tavò","Nitzavìm","Vayélech","Ha’azìnu","Vezòt Haberachà",                          // 54
                "Vayakèl & Pekudé", "Tazrìa & Metzorà", "Akharé Mot & Kedoshìm", "Behàr & Bekhukkotài", "Khukkàt & Balàk", "Mattòt & Mas’é", "Nitzavìm & Vayélech"  // 61
                ];

    var d  = new Date(anno,mese-1,giorno);
    var offset_day;
    var n_parasha;    
    var parasha;

    // Se non è Shabbat o non si legge la parasha settimanale perchè è festa, restituiamo false
    if (d.getDay() != 6) {return false;};       
    if (is_jholiday(giorno, mese, anno)){return false;}

    var dh     = GregToHeb(d);
    var yom    = dh.yom;
    var hodesh = dh.hodesh;
    var shana  = dh.shana;
    var jd_bereshit = shabbat_bereshit(shana);
    // se siamo tra Rosh Hashana e Simchat Tora, lo Shabbat Bereshit che cerchiamo è relativo all'anno ebraico precedente!
    if(hodesh==1 && yom<=23){jd_bereshit = shabbat_bereshit(shana-1);} 
    
    d.setDate (d.getDate() + 6 - d.getDay() ); // Portiamo il giorno al sabato successivo

    // Ci portiamo al primo sabato non festivo
    while (is_jholiday(d.getDate(), d.getMonth()+1, d.getFullYear() )){
        d.setDate (d.getDate() + 7);
        }  

    n_parasha=1;
    for ( var jd_temp = new Date (jd_bereshit); jd_temp.getTime()<d.getTime(); jd_temp = addDays(jd_temp,7) ){
        if (!is_jholiday(jd_temp.getDate(), jd_temp.getMonth()+1, jd_temp.getFullYear())){n_parasha++;}
    }
       
    numeri_parashot=n_parashot(shana);                                                         // la scelta dell'anno determina la scansione delle parashot
    if(hodesh==1 && yom<=23){numeri_parashot=n_parashot(shana-1);}                             // numero della parashà settimanale        
    parasha=parashot[numeri_parashot[n_parasha]];                                              // parashà settimanale
    offset_day=HebToGreg(23,1,shana).getDay();                                                // troviamo che giorno della settimana cade Simchat Tora
    if(hodesh==1 && yom>=23-offset_day && yom<=23){parasha="Bereshìt";n_parasha=1;}           // vogliamo che per una settimana almeno venga Bereshit: dalla domenica prima di Simchat Tora    
    
return parasha;
}

function Data(d){

    this.update = function(){
        this.giorno = this.data.getDate();
        this.mese   = this.data.getMonth()+1;
        this.anno   = this.data.getFullYear();
        this.w      = this.data.getDay();
    }    

    this.setData = function(d){
        if (d === undefined) {d = new Date();}
        this.data = d;
        this.update();
    }

    this.setGiorno = function(g){
        this.data.setDate(g);
        this.update();
    }

    this.setMese = function(m){
        this.data.setMonth(m-1);
        this.update();
    }

    this.setAnno = function(y){
        this.data.setFullYear(y);
        this.update();
    }

    this.setData(d);

}

function GetUrlParms(q,s) {
    s = s ? s : window.location.search;
    var re = new RegExp('&'+q+'(?:=([^&]*))?(?=&|$)','i');
    return (s=s.replace(/^\?/,'&').match(re)) ? (typeof s[1] == 'undefined' ? '' : decodeURIComponent(s[1])) : undefined;
} 
    
function caricaOrari(){
    var dh = GregToHeb( new Date(sel.anno,sel.mese-1,sel.giorno) );
    $('#lbl_oggi').html(sel.giorno + ' ' + civMonth[sel.mese] + ' ' + sel.anno );
    $('#lbl_aiom').html( dh.yom + ' ' + hodashim[dh.hodesh] + ' ' + dh.shana );
    
    if (accensione(sel.giorno,sel.mese,sel.anno)) {
        $('.accensione').show();
    } else {
        $('.accensione').hide();
    }
        
    if (uscitaStelle(sel.giorno,sel.mese,sel.anno) || isDigiunoAlbaTramonto(sel.giorno,sel.mese,sel.anno)) {
        $('.treStelle').addClass('evidenziato');
    } else {
        $('.treStelle').removeClass('evidenziato');
    }
        
    if (vigilia9av(sel.giorno,sel.mese,sel.anno)) {
        $('td.tramonto').addClass('evidenziato');
    } else {
        $('td.tramonto').removeClass('evidenziato');
    }
        
    if (isDigiunoAlbaTramonto(sel.giorno,sel.mese,sel.anno)) {
        $('td.alba').addClass('evidenziato');
    } else {
        $('td.alba').removeClass('evidenziato');
    }
        
    for ( i = 0; i < orari[sel.mese-1][sel.giorno-1].length; i++ ){
        if(sel.w==6 && i==13){$('#orari_'+i).html('<b>'+orari[sel.mese-1][sel.giorno-1][i].toFixed(2)+'</b>');}
        else                  {$('#orari_'+i).html(      orari[sel.mese-1][sel.giorno-1][i].toFixed(2)       );}
    }
}

/*
$( document ).ready(function() {
    var citta = GetUrlParms('citta');
    if (citta !== undefined ) {
    var option;
        for (var i = 0; i< $('#citta')[0].options.length-1; i++ ){
            if ( $('#citta')[0].options[i].text.toLowerCase() == citta.toLowerCase()){
                $('#citta')[0].selectedIndex = i;
                break;
            }
        } 
    }
    var d = GetUrlParms('data');
    sel = new Data();
    if (d !== undefined ) {
        var g = d.split('-');
        sel.setData(new Date (g[2],g[1]-1,g[0]));
    }
    selectLoad();
    $('#legenda').css('margin-top',$('#calendar_control').height()-5+'px');
    if ($('#chk_legenda').prop('checked') ) { 
        $('#legenda').css('margin-left',10+'px'); 
        $('#ou').css('display','inline');
    } else { 
        $('#legenda').css('margin-left',-500+'px');
        $('#ou').css('display','hidden');
    }

    $('#chk_legenda').change(function() {
        if   ($('#chk_legenda').prop('checked') ) { 
            $('#legenda').animate({'margin-left':10+'px'});
            $('#citta').prop('disabled',false);
            $('#ou').show();
        } else {
            $('#legenda').animate({'margin-left':-500+'px'});
            $('#citta').prop('disabled',true);
            $('#ou').hide();
        }
    });

    $('#luach .giornata').filter(":first").focus();
    $('#luach').on('keyup','td',function(event){console.log(event.which);} );

});
*/
